### Name: AR_Plot
### Title: Visualizing of attributable risks from case-control data
### Aliases: AR_Plot
### Keywords: manip

### ** Examples


set.seed(27092009)
dicho        <- c(0,1)
two          <- c(0,1,2)
cc_state     <- sample(dicho, 100, replace=TRUE, prob=c(0.6, 0.4))
exposure1    <- sample(dicho, 100, replace=TRUE)
exposure2    <- sample(dicho, 100, replace=TRUE, prob=c(0.2,0.8))
exposure3    <- sample(dicho, 100, replace=TRUE, prob=c(0.4,0.6))
exposure4    <- sample(dicho, 100, replace=TRUE)
confounder1  <- sample(dicho, 100, replace=TRUE, prob=c(0.3, 0.7))
confounder2  <- sample(dicho, 100, replace=TRUE)

#### 1 Exposure ####

relation     <- as.formula(cc_state~exposure1)
data_exp     <- cbind(exposure1)
AR_exposures <- AdjAR(D=cc_state, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=FALSE, 
title_plot="Example 1", legend_plot=FALSE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=FALSE, 
title_plot="Example 1", legend_plot=TRUE)

#### 1 Exposure and 1 Confounder #### 

relation     <- as.formula(cc_state~exposure1+confounder1)
data_exp     <- cbind(exposure1)
conf         <- cbind(confounder1)
AR_exposures <- AdjAR(D=cc_state,C=conf, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=TRUE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=TRUE, 
legend_plot=FALSE)

#### 1 Exposure and 2 Confounders ####

relation     <- as.formula(cc_state~exposure1+confounder1+confounder2)
data_exp     <- cbind(exposure1)
conf         <- cbind(confounder1, confounder2)
AR_exposures <- AdjAR(D=cc_state,C=conf, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=TRUE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=TRUE)

#### 2 Exposures ####  

relation     <- as.formula(cc_state~exposure1+exposure2)
data_exp     <- cbind(exposure1,exposure2)
AR_exposures <- AdjAR(D=cc_state, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=FALSE, 
legend_plot=TRUE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=FALSE)

#### 2 Exposures and 1 Confounder ####    

relation     <- as.formula(cc_state~exposure1+exposure2+confounder1)
data_exp     <- cbind(exposure1,exposure2)
conf         <- cbind(confounder1)
AR_exposures <- AdjAR(D=cc_state, C=conf, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=TRUE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=TRUE)

#### 2 Exposures and 2 Confounder ####   

relation     <- as.formula(cc_state~exposure1+exposure2+confounder1+confounder2)
data_exp     <- cbind(exposure1,exposure2)
conf         <- cbind(confounder1, confounder2)
AR_exposures <- AdjAR(D=cc_state, C=conf, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=TRUE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=TRUE)

#### 3 Expsoures ####    

relation     <- as.formula(cc_state~exposure2+exposure1+exposure4)
data_exp     <- cbind(exposure2,exposure1, exposure4)
AR_exposures <- AdjAR(D=cc_state, E=data_exp, model=relation)
AR_exposures_plot <-AR_Plot(AR_exposures, type="onlyplot", Confounding=FALSE)
AR_exposures_plot <-AR_Plot(AR_exposures, type="addplot", Confounding=FALSE)




